@@ -1,15 +1,21 @@
 suppressPackageStartupMessages({
     library(dplyr)
+    library(testthat)
 })
 
 
 
 compute_n_params <- function(cov_struct, nv) {
     n_params <- switch(cov_struct,
-        "us" = nv * (nv + 1) / 2,
-        "toep" = 2 * nv - 1,
-        "cs" = nv + 1,
-        "ar1" = 2
+        "ad" = nv,
+        "adh" = 2 * nv - 1,
+        "ar1" = 2,
+        "ar1h" = nv + 1,
+        "cs" = 2,
+        "csh" = nv + 1,
+        "toep" = nv,
+        "toeph" = 2 * nv - 1,
+        "us" = nv * (nv + 1) / 2
     )
     return(n_params)
 }
@@ -26,13 +32,6 @@ is.formula <- function(x) {
 
 expect_valid_fit_object <- function(fit, cov_struct, nv, same_cov) {
 
-    n_params <- compute_n_params(cov_struct, nv)
-
-    if (!same_cov) {
-        n_params <- 2 * n_params
-    }
-
-
     expect_type(fit, "list")
     expect_length(fit, 3)
 
@@ -44,9 +43,9 @@ expect_valid_fit_object <- function(fit, cov_struct, nv, same_cov) {
     expect_type(fit$sigma, "list")
     expect_length(fit$sigma, 2)
     expect_true(is.matrix(fit$sigma[[1]]))
-    expect_equal(dim(fit$sigma[[1]]), c(nv,nv))
+    expect_equal(dim(fit$sigma[[1]]), c(nv, nv))
     expect_true(is.matrix(fit$sigma[[2]]))
-    expect_equal(dim(fit$sigma[[2]]), c(nv,nv))
+    expect_equal(dim(fit$sigma[[2]]), c(nv, nv))
 
     expect_true(fit$failed %in% c(TRUE, FALSE))
 }
@@ -93,9 +92,9 @@ test_mmrm_numeric <- function(dat, formula_expr, same_cov, scale = FALSE) {
     formula <- as.formula(formula_expr)
     designmat <- as_model_df(dat, formula)
 
-    if(scale){
+    if (scale) {
         dat_limit <- ceiling(nrow(dat) / 2)
-        scaler <- scalerConstructor$new(designmat[seq_len(dat_limit),])
+        scaler <- scalerConstructor$new(designmat[seq_len(dat_limit), ])
         dmat <- scaler$scale(designmat)
     } else {
         dmat <- designmat
@@ -112,7 +111,7 @@ test_mmrm_numeric <- function(dat, formula_expr, same_cov, scale = FALSE) {
         same_cov = same_cov
     )
 
-    if(scale){
+    if (scale) {
         fit_actual$beta <- scaler$unscale_beta(fit_actual$beta)
         fit_actual$sigma <- lapply(fit_actual$sigma, function(x) scaler$unscale_sigma(x))
     }
@@ -185,7 +184,7 @@ args_default <- list(
 
 test_that("as_mmrm_df & as_mmrm_formula", {
 
-    sigma <- as_vcov(c(2, 6, 3), c(0.4,0.7,0.5))
+    sigma <- as_vcov(c(2, 6, 3), c(0.4, 0.7, 0.5))
     dat <- get_sim_data(100, sigma)
 
 
@@ -240,38 +239,45 @@ test_that("as_mmrm_df & as_mmrm_formula", {
 
 
 
-test_that("MMRM model fit has expected output structure (same_cov = TRUE)",{
+test_that("MMRM model fit has expected output structure", {
+    for (struct in c("ad", "adh", "ar1", "ar1h", "cs", "csh", "toep", "toeph", "us")) {
 
-    ############# US
-    args <- args_default
-    args$cov_struct <- "us"
-    fit <- do.call(fit_mmrm, args = args)
-    expect_valid_fit_object(fit, "us", 3, TRUE)
+        ## First for same covariance per group
+        args <- args_default
+        args$cov_struct <- struct
+        fit <- do.call(fit_mmrm, args = args)
+        expect_valid_fit_object(fit, struct, 3, TRUE)
 
 
-    ############# TOEP
-    args <- args_default
-    args$cov_struct <- "toep"
-    fit <- do.call(fit_mmrm, args = args)
-    expect_valid_fit_object(fit, "toep", 3, TRUE)
+        mod <- mmrm::mmrm(
+            formula = as.formula(sprintf("outcome ~ sex + age + visit * group + %s(visit | id)", struct)),
+            data = dat,
+            reml = TRUE
+        )
+        expect_equal(length(mod$theta_est), compute_n_params(struct, 3))
+        expect_equal(fit$beta, coef(mod), ignore_attr = TRUE)
+        expect_equal(fit$sigma[[1]], VarCorr(mod), ignore_attr = TRUE)
 
+        ## And again for difference covariance per group
+        args <- args_default
+        args$cov_struct <- struct
+        args$same_cov <- FALSE
+        fit <- do.call(fit_mmrm, args = args)
+        expect_valid_fit_object(fit, struct, 3, FALSE)
 
-    ############# CS
-    args <- args_default
-    args$cov_struct <- "cs"
-    fit <- do.call(fit_mmrm, args = args)
-    expect_valid_fit_object(fit, "cs", 3, TRUE)
-
-
-    ############# AR1
-    args <- args_default
-    args$cov_struct <- "ar1"
-    fit <- do.call(fit_mmrm, args = args)
-    expect_valid_fit_object(fit, "ar1", 3, TRUE)
+        mod <- mmrm::mmrm(
+            formula = as.formula(sprintf("outcome ~ sex + age + visit * group + %s(visit | group / id)", struct)),
+            data = dat,
+            reml = TRUE
+        )
+        expect_equal(length(mod$theta_est), compute_n_params(struct, 3) * 2)
+        expect_equal(fit$beta, coef(mod), ignore_attr = TRUE)
+        expect_equal(fit$sigma, VarCorr(mod), ignore_attr = TRUE)
+    }
 })
 
 
-test_that("MMRM model fit has expected output structure (same_cov = FALSE)",{
+test_that("MMRM model fit has expected output structure (same_cov = FALSE)", {
     args <- args_default
     args$same_cov <- FALSE
     fit <- do.call(fit_mmrm, args = args)
@@ -378,63 +384,6 @@ test_that("MMRM returns expected estimates under different model specifications"
 })
 
 
-##### Current usage of mmrm has gotten rid of initial values
-##### re-implement if we decide to optimise mmrm
-#
-#
-# test_that("initial values speed up BFGS", {
-#
-#     set.seed(315)
-#     sigma <- as_vcov(c(5, 3, 8), c(0.4, 0.6, 0.3))
-#
-#     dat <- get_sim_data(n = 200, sigma)
-#
-#     vars <- set_vars(
-#         subjid = "id",
-#         covariates = c("group", "sex", "visit * group")
-#     )
-#
-#     frm <- as_simple_formula(vars$outcome, c(vars$group, vars$visit, vars$covariates))
-#     model_df <- as_model_df(dat = dat, frm = frm)
-#
-#     x <- time_it({
-#         fit <- fit_mmrm_multiopt(
-#             designmat = model_df[, -1, drop = FALSE],
-#             outcome = as.data.frame(model_df)[, 1],
-#             subjid = dat[[vars$subjid]],
-#             visit = dat[[vars$visit]],
-#             group = dat[[vars$group]],
-#             cov_struct = "us",
-#             REML = TRUE,
-#             same_cov = TRUE,
-#             optimizer = "BFGS"
-#         )
-#     })
-#
-#     y <- time_it({
-#         fit2 <- fit_mmrm_multiopt(
-#             designmat = model_df[, -1, drop = FALSE],
-#             outcome = as.data.frame(model_df)[, 1],
-#             subjid = dat[[vars$subjid]],
-#             visit = dat[[vars$visit]],
-#             group = dat[[vars$group]],
-#             cov_struct = "us",
-#             REML = TRUE,
-#             same_cov = TRUE,
-#             optimizer = list(
-#                 BFGS = fit[c("beta", "theta")]
-#             )
-#         )
-#     })
-#
-#     expect_true(
-#         (as.numeric(x) * 0.5) > as.numeric(y)
-#     )
-# })
-
-
-
-
 test_that("visit & group factor levels / order doesn't break model extraction", {
     set.seed(3812)
     bign <- 120
@@ -490,4 +439,3 @@ test_that("visit & group factor levels / order doesn't break model extraction",
     expect_equal(expected, extract_params(mod)$sigma$A)
 
 })
-
